# Generated by Django 5.0.4 on 2024-04-22 20:44

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('artd_urls', '0002_alter_url_partner_alter_urlconfiguration_partner'),
    ]

    operations = [
        migrations.RenameField(
            model_name='url',
            old_name='decorator',
            new_name='decorators',
        ),
    ]



# Generated by Django 5.0.4 on 2024-04-22 20:42

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('artd_partner', '0005_alter_coworker_created_at_alter_coworker_updated_at_and_more'),
        ('artd_urls', '0001_initial'),
    ]

    operations = [
        migrations.AlterField(
            model_name='url',
            name='partner',
            field=models.OneToOneField(help_text='Select the partner', on_delete=django.db.models.deletion.CASCADE, to='artd_partner.partner', verbose_name='Partner'),
        ),
        migrations.AlterField(
            model_name='urlconfiguration',
            name='partner',
            field=models.OneToOneField(help_text='Select the partner', on_delete=django.db.models.deletion.CASCADE, to='artd_partner.partner', verbose_name='Partner'),
        ),
    ]



# Generated by Django 5.0.4 on 2024-04-22 20:33

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        ('artd_partner', '0005_alter_coworker_created_at_alter_coworker_updated_at_and_more'),
    ]

    operations = [
        migrations.CreateModel(
            name='Url',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created_at', models.DateTimeField(auto_now_add=True, verbose_name='Created at')),
                ('updated_at', models.DateTimeField(auto_now=True, verbose_name='Updated at')),
                ('status', models.BooleanField(default=True, verbose_name='status')),
                ('url', models.CharField(blank=True, help_text='Enter the url of the product', max_length=250, null=True, verbose_name='Url')),
                ('module', models.CharField(blank=True, help_text='Enter the module of the product', max_length=250, null=True, verbose_name='Module')),
                ('name', models.CharField(blank=True, help_text='Enter the name of the product', max_length=250, null=True, verbose_name='Name')),
                ('decorator', models.CharField(blank=True, help_text='Enter the decorator of the product', max_length=250, null=True, verbose_name='Decorator')),
                ('partner', models.ForeignKey(help_text='Select the partner', on_delete=django.db.models.deletion.CASCADE, to='artd_partner.partner', verbose_name='Partner')),
            ],
            options={
                'verbose_name': 'Url',
                'verbose_name_plural': 'Urls',
            },
        ),
        migrations.CreateModel(
            name='UrlConfiguration',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created_at', models.DateTimeField(auto_now_add=True, verbose_name='Created at')),
                ('updated_at', models.DateTimeField(auto_now=True, verbose_name='Updated at')),
                ('status', models.BooleanField(default=True, verbose_name='status')),
                ('include_admin_urls', models.BooleanField(default=True, help_text='Include the admin urls in the list', verbose_name='Include Admin URLs')),
                ('include_dinamic_urls', models.BooleanField(default=True, help_text='Include the dinamic urls in the list', verbose_name='Include Dinamic URLs')),
                ('partner', models.ForeignKey(help_text='Select the partner', on_delete=django.db.models.deletion.CASCADE, to='artd_partner.partner', verbose_name='Partner')),
            ],
            options={
                'verbose_name': 'Url Configuration',
                'verbose_name_plural': 'Url Configurations',
            },
        ),
    ]



from django.contrib import admin
from django.db import models
from django.utils.translation import gettext_lazy as _
from dal import autocomplete
from artd_urls.models import Url, UrlConfiguration


@admin.register(UrlConfiguration)
class UrlConfigurationAdmin(admin.ModelAdmin):
    list_display = (
        "partner",
        "include_admin_urls",
        "include_dinamic_urls",
        "status",
    )
    search_fields = (
        "partner__name",
        "include_admin_urls",
        "include_dinamic_urls",
    )
    readonly_fields = [
        "created_at",
        "updated_at",
    ]
    fieldsets = (
        (
            _("Configuration"),
            {
                "fields": (
                    "partner",
                    "include_admin_urls",
                    "include_dinamic_urls",
                )
            },
        ),
        (
            _("Status Information"),
            {
                "fields": ("status",),
            },
        ),
        (
            _("Timestamps"),
            {
                "fields": (
                    "created_at",
                    "updated_at",
                )
            },
        ),
    )


@admin.register(Url)
class UrlAdmin(admin.ModelAdmin):
    list_display = (
        "partner",
        "url",
        "status",
    )
    search_fields = (
        "partner__name",
        "url",
        "module",
        "name",
        "decorators",
    )
    readonly_fields = [
        "partner",
        "url",
        "module",
        "name",
        "decorators",
        "created_at",
        "updated_at",
        "status",
    ]
    fieldsets = (
        (
            _("Configuration"),
            {
                "fields": (
                    "partner",
                    "url",
                    "module",
                    "name",
                    "decorators",
                )
            },
        ),
        (
            _("Status Information"),
            {
                "fields": ("status",),
            },
        ),
        (
            _("Timestamps"),
            {
                "fields": (
                    "created_at",
                    "updated_at",
                )
            },
        ),
    )
    formfield_overrides = {
        models.ManyToManyField: {"widget": autocomplete.ModelSelect2Multiple()},
    }

    def has_add_permission(self, request):
        return False



from django.urls import get_resolver


def get_all_urls():
    resolver = get_resolver()
    all_urls = []

    def extract_urls(patterns, namespace=""):
        for pattern in patterns:
            if hasattr(pattern, "url_patterns"):
                new_namespace = (
                    namespace + pattern.namespace + ":"
                    if pattern.namespace
                    else namespace
                )
                extract_urls(pattern.url_patterns, new_namespace)
            if hasattr(pattern, "pattern"):
                url = namespace + pattern.pattern.regex.pattern
                callback = pattern.callback
                if callback:
                    callback_info = f"{callback.__module__}.{callback.__name__}"
                else:
                    callback_info = "No callback"
                all_urls.append((url, callback_info))

    extract_urls(resolver.url_patterns)
    return all_urls



from django.db import models
from django.utils.translation import gettext_lazy as _
from artd_partner.models import Partner


class UrlBaseModel(models.Model):

    created_at = models.DateTimeField(
        _("Created at"),
        auto_now_add=True,
    )
    updated_at = models.DateTimeField(
        _("Updated at"),
        auto_now=True,
    )
    status = models.BooleanField(
        _("status"),
        default=True,
    )

    class Meta:
        abstract = True


class UrlConfiguration(UrlBaseModel):
    """Model definition for Url Configuration."""

    partner = models.OneToOneField(
        Partner,
        verbose_name=_("Partner"),
        help_text=_("Select the partner"),
        on_delete=models.CASCADE,
    )
    include_admin_urls = models.BooleanField(
        _("Include Admin URLs"),
        help_text=_("Include the admin urls in the list"),
        default=True,
    )
    include_dinamic_urls = models.BooleanField(
        _("Include Dinamic URLs"),
        help_text=_("Include the dinamic urls in the list"),
        default=True,
    )

    class Meta:
        """Meta definition for Url Configuration."""

        verbose_name = _("Url Configuration")
        verbose_name_plural = _("Url Configurations")

    def __str__(self):
        """Unicode representation of Url Configuration."""
        return self.partner.name


class Url(UrlBaseModel):
    """Model definition for Url."""

    partner = models.ForeignKey(
        Partner,
        verbose_name=_("Partner"),
        help_text=_("Select the partner"),
        on_delete=models.CASCADE,
    )
    url = models.CharField(
        _("Url"),
        help_text=_("Enter the url of the product"),
        max_length=250,
        null=True,
        blank=True,
    )
    module = models.CharField(
        _("Module"),
        help_text=_("Enter the module of the product"),
        max_length=250,
        null=True,
        blank=True,
    )
    name = models.CharField(
        _("Name"),
        help_text=_("Enter the name of the product"),
        max_length=250,
        null=True,
        blank=True,
    )
    decorators = models.CharField(
        _("Decorator"),
        help_text=_("Enter the decorator of the product"),
        max_length=250,
        null=True,
        blank=True,
    )

    class Meta:
        """Meta definition for Url."""

        verbose_name = _("Url")
        verbose_name_plural = _("Urls")

    def __str__(self):
        """Unicode representation of Url."""
        return self.name
